@@ -697,14 +697,18 @@ class UploadForm {
 	 */
 	function verifyExtension( $mime, $extension ) {
 		$fname = 'SpecialUpload::verifyExtension';
-		
-		if (!$mime || $mime=="unknown" || $mime=="unknown/unknown") {
-			wfDebug( "$fname: passing file with unknown mime type\n" );
-			return true; 
-		}
-		
-		$magic=& wfGetMimeMagic();
-		
+
+		$magic =& wfGetMimeMagic();
+
+		if ( ! $mime || $mime == 'unknown' || $mime == 'unknown/unknown' )
+			if ( ! $magic->isRecognizableExtension( $extension ) ) {
+				wfDebug( "$fname: passing file with unknown detected mime type; unrecognized extension '$extension', can't verify\n" );
+				return true;
+			} else {
+				wfDebug( "$fname: rejecting file with unknown detected mime type; recognized extension '$extension', so probably invalid file\n" );
+				return false;
+			}
+
 		$match= $magic->isMatchingExtension($extension,$mime);
 		
 		if ($match===NULL) {
