@@ -3,12 +3,6 @@
  * @package MediaWiki
  * @subpackage Language
  */
-   
-
-# The names of the namespaces can be set here, but the numbers
-# are magical, so don't change or move them!  The Namespace class
-# encapsulates some of the magic-ness.
-#
 
 # Most of this was written by Ævar Arnfjörð Bjarmason <avarab@gmail.com>
 
@@ -25,8 +19,8 @@ require_once( 'LanguageUtf8.php' );
 	NS_PROJECT_TALK		=> $wgMetaNamespace . 'spjall',
 	NS_IMAGE		=> 'Mynd',
 	NS_IMAGE_TALK		=> 'Myndaspjall',
-	NS_MEDIAWIKI		=> 'Kerfismelding',
-	NS_MEDIAWIKI_TALK	=> 'Kerfismeldingarspjall',
+	NS_MEDIAWIKI		=> 'Melding',
+	NS_MEDIAWIKI_TALK	=> 'Meldingarspjall',
 	NS_TEMPLATE		=> 'Snið',
 	NS_TEMPLATE_TALK	=> 'Sniðaspjall',
 	NS_HELP			=> 'Hjálp',
@@ -43,19 +37,29 @@ require_once( 'LanguageUtf8.php' );
 	'standard'	=> 'Klassískt',
 	'nostalgia'	=> 'Gamaldags',
 	'cologneblue'	=> 'Kölnarblátt',
-	'davinci'	=> 'DaVinci',
-	'mono'		=> 'Mono',
-	'monobook'	=> 'MonoBook',
 	'myskin'	=> 'Mitt þema',
-	'chick'		=> 'Chick'
+) + $wgSkinNamesEn;
+
+/* private */ $wgDateFormatsIs = array(
+	'Sjálfgefið',
+	'15. janúar 2001 kl. 16:12',
+	'15. jan. 2001 kl. 16:12',
+	'16:12, 15. janúar 2001',
+	'16:12, 15. jan. 2001',
+	'ISO 8601' => '2001-01-15 16:12:34'
 );
 
+$wgMagicWordsIs = array(
+	MAG_REDIRECT             => array( 0,    '#redirect', '#tilvísun', '#TILVÍSUN' ), // MagicWord::initRegex() sucks
+) + $wgMagicWordsEn;
+
 #-------------------------------------------------------------------
 # Default messages
 #-------------------------------------------------------------------
 
 $wgAllMessagesIs = array(
-'linktrail' => '/^([áðéíóúýþæöa-z]+)(.*)$/sDu',
+'linktrail' => '/^([áðéíóúýþæöa-z-–]+)(.*)$/sDu',
+'linkprefix'=> '/^(.*?)([áÁðÐéÉíÍóÓúÚýÝþÞæÆöÖA-Za-z-–]+)$/sDu',
 
 '1movedto2' => "$1 færð á $2",
 '1movedto2_redir' => "$1 færð á $2 yfir tilvísun",
@@ -67,54 +71,53 @@ $wgAllMessagesIs = array(
 ",
 'Monobook.js' => "/* tooltips and access keys */
 ta = new Object();
-ta['pt-userpage'] = new Array('.','Notendasíðan mín'); 
-ta['pt-anonuserpage'] = new Array('.','Notendasíðan fyrir IP töluna þína'); 
-ta['pt-mytalk'] = new Array('n','Spallsíðan mín'); 
-ta['pt-anontalk'] = new Array('n','Spjallsíðan fyrir þessa IP tölu'); 
-ta['pt-preferences'] = new Array('','Almennar stillingar'); 
-ta['pt-watchlist'] = new Array('l','Vaktlistinn.'); 
-ta['pt-mycontris'] = new Array('y','Listi yfir framlög þín'); 
-ta['pt-login'] = new Array('o','Þú ert hvattur/hvött til að innskrá þig, það er hinsvegar ekki nauðsynlegt.'); 
-ta['pt-anonlogin'] = new Array('o','Þú ert hvattur/hvött til að innskrá þig, það er hinsvegar ekki nauðsynlegt.'); 
-ta['pt-logout'] = new Array('o','Útskráning'); 
-ta['ca-talk'] = new Array('t','Spallsíða þessarar síðu'); 
-ta['ca-edit'] = new Array('e','Þú getur breytt síðu þessari, vinsamlegast notaðu „forskoða“ hnappinn áður en þú vistar'); 
-ta['ca-addsection'] = new Array('+','Viðbótarumræða.'); 
-ta['ca-viewsource'] = new Array('e','Síða þessi er vernduð, þú getur þó skoðað frumkóða hennar.'); 
-ta['ca-history'] = new Array('h','Eldri útgáfur af síðunni.'); 
-ta['ca-protect'] = new Array('=','Vernda þessa síðu'); 
-ta['ca-delete'] = new Array('d','Eyða þessari síðu'); 
-ta['ca-undelete'] = new Array('d','Endurvekja breytingar á síðu þessari fyrir en henni var tortímt'); 
-ta['ca-move'] = new Array('m','Færa þessa síðu'); 
-ta['ca-nomove'] = new Array('','Þér er óheimild að færa þessa síðu'); 
-ta['ca-watch'] = new Array('w','Bæta þessari síðu við á vaktlistann'); 
-ta['ca-unwatch'] = new Array('w','Fjarlægja þessa síðu af vaktlistanum'); 
-ta['search'] = new Array('f','Leit'); 
-ta['p-logo'] = new Array('','Forsíða'); 
-ta['n-mainpage'] = new Array('z','Forsíða {{SITENAME}}'); 
-ta['n-portal'] = new Array('','Um verkefnið, hvernig er hægt að hjálpa og hvar á að byrja'); 
-ta['n-currentevents'] = new Array('','Líðandi stund'); 
-ta['n-recentchanges'] = new Array('r','Listi yfir nýlegar breytingar.'); 
-ta['n-randompage'] = new Array('x','Handahófsvalin síða'); 
-ta['n-help'] = new Array('','Efnisyfirlit yfir hjálparsíður.'); 
-ta['n-sitesupport'] = new Array('','Fjárframlagssíða Wikimedia'); 
-ta['t-whatlinkshere'] = new Array('j','Listi yfir síður sem tengjast í þessa'); 
-ta['t-recentchangeslinked'] = new Array('k','Nýlegar breitingar á ítengdum síðum'); 
-ta['feed-rss'] = new Array('','RSS fyrir þessa síðu'); 
-ta['feed-atom'] = new Array('','Atom fyrir þessa síðu'); 
-ta['t-contributions'] = new Array('','Sýna framlagslista þessa notanda'); 
-ta['t-emailuser'] = new Array('','Senda notanda þessum póst'); 
-ta['t-upload'] = new Array('u','Innhlaða myndum eða margmiðlunarskrám'); 
-ta['t-specialpages'] = new Array('q','Listi yfir kerfissíður'); 
-ta['ca-nstab-main'] = new Array('c','Sýna síðuna'); 
-ta['ca-nstab-user'] = new Array('c','Sýna notendasíðuna'); 
-ta['ca-nstab-media'] = new Array('c','Sýna margmiðlunarsíðuna'); 
-ta['ca-nstab-special'] = new Array('','Þetta er kerfissíða, þér er óhæft að breyta henni.'); 
-ta['ca-nstab-wp'] = new Array('a','Sýna verkefnasíðuna'); 
-ta['ca-nstab-image'] = new Array('c','Sýna myndasíðuna'); 
-ta['ca-nstab-mediawiki'] = new Array('c','Sýna kerfisskilaboðin'); 
-ta['ca-nstab-template'] = new Array('c','View the template'); 
-ta['ca-nstab-help'] = new Array('c','Sýna hjálparsíðuna'); 
+ta['pt-userpage'] = new Array('.','Notendasíðan mín');
+ta['pt-anonuserpage'] = new Array('.','Notendasíðan fyrir IP töluna þína');
+ta['pt-mytalk'] = new Array('n','Spallsíðan mín');
+ta['pt-anontalk'] = new Array('n','Spjallsíðan fyrir þessa IP tölu');
+ta['pt-preferences'] = new Array('','Almennar stillingar');
+ta['pt-watchlist'] = new Array('l','Vaktlistinn.');
+ta['pt-mycontris'] = new Array('y','Listi yfir framlög þín');
+ta['pt-login'] = new Array('o','Þú ert hvattur/hvött til að innskrá þig, það er hinsvegar ekki nauðsynlegt.');
+ta['pt-anonlogin'] = new Array('o','Þú ert hvattur/hvött til að innskrá þig, það er hinsvegar ekki nauðsynlegt.');
+ta['pt-logout'] = new Array('o','Útskráning');
+ta['ca-talk'] = new Array('t','Spallsíða þessarar síðu');
+ta['ca-edit'] = new Array('e','Þú getur breytt síðu þessari, vinsamlegast notaðu „forskoða“ hnappinn áður en þú vistar');
+ta['ca-addsection'] = new Array('+','Viðbótarumræða.');
+ta['ca-viewsource'] = new Array('e','Síða þessi er vernduð, þú getur þó skoðað frumkóða hennar.');
+ta['ca-history'] = new Array('h','Eldri útgáfur af síðunni.');
+ta['ca-protect'] = new Array('=','Vernda þessa síðu');
+ta['ca-delete'] = new Array('d','Eyða þessari síðu');
+ta['ca-undelete'] = new Array('d','Endurvekja breytingar á síðu þessari fyrir en henni var tortímt');
+ta['ca-move'] = new Array('m','Færa þessa síðu');
+ta['ca-watch'] = new Array('w','Bæta þessari síðu við á vaktlistann');
+ta['ca-unwatch'] = new Array('w','Fjarlægja þessa síðu af vaktlistanum');
+ta['search'] = new Array('f','Leit');
+ta['p-logo'] = new Array('','Forsíða');
+ta['n-mainpage'] = new Array('z','Forsíða {{SITENAME}}');
+ta['n-portal'] = new Array('','Um verkefnið, hvernig er hægt að hjálpa og hvar á að byrja');
+ta['n-currentevents'] = new Array('','Líðandi stund');
+ta['n-recentchanges'] = new Array('r','Listi yfir nýlegar breytingar.');
+ta['n-randompage'] = new Array('x','Handahófsvalin síða');
+ta['n-help'] = new Array('','Efnisyfirlit yfir hjálparsíður.');
+ta['n-sitesupport'] = new Array('','Fjárframlagssíða Wikimedia');
+ta['t-whatlinkshere'] = new Array('j','Listi yfir síður sem tengjast í þessa');
+ta['t-recentchangeslinked'] = new Array('k','Nýlegar breitingar á ítengdum síðum');
+ta['feed-rss'] = new Array('','RSS fyrir þessa síðu');
+ta['feed-atom'] = new Array('','Atom fyrir þessa síðu');
+ta['t-contributions'] = new Array('','Sýna framlagslista þessa notanda');
+ta['t-emailuser'] = new Array('','Senda notanda þessum póst');
+ta['t-upload'] = new Array('u','Innhlaða myndum eða margmiðlunarskrám');
+ta['t-specialpages'] = new Array('q','Listi yfir kerfissíður');
+ta['ca-nstab-main'] = new Array('c','Sýna síðuna');
+ta['ca-nstab-user'] = new Array('c','Sýna notendasíðuna');
+ta['ca-nstab-media'] = new Array('c','Sýna margmiðlunarsíðuna');
+ta['ca-nstab-special'] = new Array('','Þetta er kerfissíða, þér er óhæft að breyta henni.');
+ta['ca-nstab-wp'] = new Array('a','Sýna verkefnasíðuna');
+ta['ca-nstab-image'] = new Array('c','Sýna myndasíðuna');
+ta['ca-nstab-mediawiki'] = new Array('c','Sýna kerfisskilaboðin');
+ta['ca-nstab-template'] = new Array('c','View the template');
+ta['ca-nstab-help'] = new Array('c','Sýna hjálparsíðuna');
 ta['ca-nstab-category'] = new Array('c','Sýna efnisflokkasíðuna');",
 'about' => "Um",
 'aboutpage' => "Project:Um",
@@ -124,32 +127,28 @@ ta['ca-nstab-category'] = new Array('c','Sýna efnisflokkasíðuna');",
 'acct_creation_throttle_hit' => "Fyrirgefðu, þú hefur nú þegar búið til $1 aðgang(a). Þú getur ekki búið til fleiri.",
 'actioncomplete' => "Aðgerð lokið",
 'addedwatch' => "Bætt á vaktlistann",
-'addedwatchtext' => "Síðunni „$1“ hefur verið bætt á [[Special:Watchlist|Vaktlistann]] þinn. 
+'addedwatchtext' => "Síðunni „$1“ hefur verið bætt á [[Special:Watchlist|Vaktlistann]] þinn.
 Frekari breytingar á henni eða spallsíðu hennar munu verða sýndar þar.
 Þar að auki verður síða þessi '''feitletruð''' á [[Special:Recentchanges|Nýlegum breytingum]]
 svo auðveldara sé að sjá hana þar meðal fjöldans.
 
 <p>Til að fjarlægja síðu þessa af vaktlistanum þarft þú að ýta á tengilinn er merktur er „afvakta“.",
 'administrators' => "{{ns:4}}:Stjórnendur",
-'affirmation' => "Ég staðfesti að rétthafi þessa efnis veitir leyfi fyrir notkun þess undir $1.. Eða að efni þetta er ekki verndað af höfundalögum.",
 'allmessages' => "Kerfismeldingar",
 'allmessagescurrent' => "Núverandi texti",
 'allmessagesdefault' => "Sjálfgefinn texti",
 'allmessagesname' => "Titill",
 'allmessagestext' => "Listi yfir meldingar í „{{ns:8}}“ nafnarýminu.",
 'allpages' => "Allar síður",
-'allpagesformtext2' => "Nafnrými: $1 $2",
 'alphaindexline' => "$1 til $2",
-'alreadyloggedin' => "<font color=red><b>Notandinn $1 er þegar innskráður!</b></font><br/>",
+'alreadyloggedin' => "<strong>Notandinn $1 er þegar innskráður!</strong><br />",
 'ancientpages' => "Elstu síður",
 'anontalkpagetext' => "----Þetta er spjallsíða fyrir óskráðan notanda sem hefur ekki búið til aðgang enn þá eða notar hann ekki, slíkir notendur þekkjast á [[IP tala|IP tölu]] sinni. Það getur gerst að margir notendur deili sömu IP tölu þannig að athugasemdum sem beint er til eins notanda geta birst á spjallsíðu annars. [[Special:Userlogin|Skráðu þig sem notanda]] til að koma í veg fyrir svona misskilning.''",
 'apr' => "apr",
 'april' => "apríl",
-'articleexists' => "Annaðhvort er þegar til síða undir þessum titli, 
-eða sá titill sem þú hefur valið er ekki gildur. 
+'articleexists' => "Annaðhvort er þegar til síða undir þessum titli,
+eða sá titill sem þú hefur valið er ekki gildur.
 Vinsamlegast veldu annan titil.",
-'articlenamespace' => "(greinar)",
-'asksql' => "Gagnagrunnsfyrirspurn",
 'aug' => "ágú",
 'august' => "ágúst",
 'badfilename' => "Skáarnafninu hefur verið breytt í „$1“.",
@@ -158,7 +157,7 @@ Vinsamlegast veldu annan titil.",
 'badtitletext' => "Umbeðin síðutitill er ógildur.",
 'blanknamespace' => "(Aðalnafnrýmið)",
 'blockip' => "Banna notanda",
-'blockipsuccesstext' => "„$1“ hefur verið bannaður.<br/>
+'blockipsuccesstext' => "„$1“ hefur verið bannaður.<br />
 Sjá [[Special:Ipblocklist|bannaðar notendur og IP tölur]] fyrir yfirlit yfir núverandi bönn.",
 'blockiptext' => "Hægt er að hindra einstaka notendur eða IP tölur í að gera breytingar á {{SITENAME}}
 
@@ -166,16 +165,16 @@ Sjá [[Special:Ipblocklist|bannaðar notendur og IP tölur]] fyrir yfirlit yfir
 
 Sjá [[meta:Range blocks|Range blocks]] á meta fyrir yfirlit yfir [[CIDR]] tölur, [[{{ns:Special}}:Ipblocklist|bannaða notendur og IP tölur]] fyrir lista yfir þá sem nú eru bannaðir og [[{{ns:4}}:Bönnunarskrá|bönnunarskrá]] fyrir lista sem inniheldur einnig þá sem hafa verið bannaðir í fortíðinni.",
 'blocklink' => "banna",
-'blocklistline' => "$1, $2 bannaði $3 (rennur út $4)",
+'blocklistline' => "$1, $2 bannaði $3 ($4)",
+'infiniteblock' => 'rennur út infinite', //fixme
+'expiringblock' => 'rennur út  $1',
 'blocklogpage' => "Bönnunarskrá",
-'blocklogtext' => "This is a log of user blocking and unblocking actions. Automatically 
+'blocklogtext' => "This is a log of user blocking and unblocking actions. Automatically
 blocked IP addresses are not be listed. See the [[Special:Ipblocklist|IP block list]] for
 the list of currently operational bans and blocks.",
 'bold_sample' => "Feitletraður texti",
 'bold_tip' => "Feitletraður texti",
 'booksources' => "Bókabúðir",
-'bureaucratlog' => "Möppudýraskrá",
-'bureaucratlogentry' => "Réttindi „$1“ stillt á „$2“",
 'bureaucrattext' => "[[{{ns:4}}:Möppudýr|Möppudýrsréttindi]] eru skilyrði fyrir því að nota þessa kerfissíðu.",
 'bureaucrattitle' => "Möppudýrsréttinda þörf",
 'bydate' => "eftir dagsetningu",
@@ -191,7 +190,7 @@ the list of currently operational bans and blocks.",
 'categoryarticlecount1' => "Það er $1 síða í þessum flokki.",
 'changepassword' => "Breyta lykilorði",
 'changes' => "Breytingar",
-'clearyourcache' => "'''Ath:''' Eftir að þú hefur vistað breytingar þarf að hreynsa flýtiskrár vafrarans til að sjá þær, í '''Mozilla / Konqueror''' ''CTRL-r'', '''IE / Opera:''' ''CTRL-F5'', '''Safari:''' ''CMD-r''.",
+'clearyourcache' => "'''Ath:''' Eftir að þú hefur vistað breytingar þarf að hreynsa flýtiskrár vafrarans til að sjá þær, í '''Mozilla / Firefox''' ''CTRL-Shift-R'', '''IE:''' ''CTRL-F5'', '''Safari:''' ''CMD-Shift-R'', '''Konqueror:''' ''F5''.",
 'columns' => "Dálkar",
 'compareselectedversions' => "Bera saman valdar útgáfur",
 'confirm' => "Staðfesta",
@@ -211,8 +210,8 @@ the list of currently operational bans and blocks.",
 'createaccount' => "Nýskrá",
 'createaccountmail' => "með netfangi",
 'cur' => "nú",
-'currentevents' => "Potturinn",
-'currentevents-url' => "{{ns:4}}:Potturinn",
+'currentevents' => "Líðandi stund",
+'currentevents-url' => "Líðandi stund",
 'currentrev' => "Núverandi útgáfa",
 'currentrevisionlink' => "núverandi útgáfa",
 'databaseerror' => "Gagnagrunnsvilla",
@@ -236,7 +235,7 @@ the list of currently operational bans and blocks.",
 'diff' => "breyting",
 'difference' => "(Munur milli útgáfa)",
 'disambiguations' => "Aðgreiningarsíður",
-'disambiguationstext' => "The following pages link to a <i>disambiguation page</i>. They should link to the appropriate topic instead.<br/>A page is treated as dismbiguation if it is linked from $1.<br/>Links from other namespaces are <i>not</i> listed here.",
+'disambiguationstext' => "The following pages link to a <i>disambiguation page</i>. They should link to the appropriate topic instead.<br />A page is treated as dismbiguation if it is linked from $1.<br />Links from other namespaces are <i>not</i> listed here.",
 'disclaimerpage' => "Project:Almennur fyrirvari",
 'disclaimers' => "Fyrirvarar",
 'edit' => "Breyta",
@@ -264,7 +263,7 @@ the list of currently operational bans and blocks.",
 of when the lock will be released", */
 'error' => "Villa",
 'errorpagetitle' => "Villa",
-'excontent' => "innihaldið var:",
+'excontent' => "innihaldið var: '$1'",
 'explainconflict' => "Síðunni hefur verið breytt síðan þú byrjaðir að gera breytingar á henni, textinn í efri reitnum inniheldur núverandi útgáfu úr gagnagrunni og sá neðri inniheldur þína útgáfu, þú þarft hér að færa breytingar sem þú vilt halda úr neðri reitnum í þann efri og vista síðuna. <strong>Aðeins</strong> texti úr efri reitnum mun vera vistaður þegar þú vistar.",
 'export' => "XML útgáfa síðu",
 'exportcuronly' => "Aðeins núverandi útgáfu án breytingarskrá",
@@ -297,7 +296,6 @@ upplýsingar um hana.",
 'historywarning' => "Athugið: Síðan sem þú ert um það bil að eyða á sér&nbsp;",
 'hr_tip' => "Lárétt lína (notist sparlega)",
 'ignorewarning' => "Hunsa viðvörun og vista þessa útgáfu.",
-'ilshowmatch' => "Sýna allar skrár með nöfn sem passa við",
 'ilsubmit' => "Leita",
 'image_sample' => "Sýnishorn.jpeg",
 'image_tip' => "Setja inn mynd",
@@ -311,7 +309,7 @@ upplýsingar um hana.",
 
 Legend: (nú) = núverandi útgáfa,
 (eyða) = eyða þessari útgáfu, (nota) = nota þessa útgáfu í stað núverandi útgáfu.
-<br/><em>Fylgdu dagsetningartenglunum til að sjá mynd sem hlaðið var inn á þeim tíma</em>.",
+<br /><em>Fylgdu dagsetningartenglunum til að sjá mynd sem hlaðið var inn á þeim tíma</em>.",
 'imghistory' => "Breytingaskrá myndar",
 'imglegend' => "Skýringar: (lýsing) = sýna og/eða breyta lýsingu skráar.",
 'ipaddress' => "IP Tala/notendanafn",
@@ -337,7 +335,6 @@ Legend: (nú) = núverandi útgáfa,
 'linklistsub' => "(Listi yfir ítengdar síður)",
 'linkshere' => "Eftirfarandi síður tengjast hingað:",
 'linkstoimage' => "Eftirfarandi síður tengjast í mynd þessa:",
-'listadmins' => "Stjórnendalisti",
 'listingcontinuesabbrev' => " frh.",
 'listusers' => "Notendalisti",
 'localtime' => "Staðartími",
@@ -369,12 +366,12 @@ Legend: (nú) = núverandi útgáfa,
 'media_sample' => "Sýnishorn.ogg",
 'media_tip' => "Tengill í margmiðlunarskrá",
 'minoredit' => "Minniháttar breyting",
-'missingimage' => "<b>Mynd vantar</b><br/><i>$1</i>",
+'missingimage' => "<b>Mynd vantar</b><br /><i>$1</i>",
 'monday' => "mánudagur",
 'move' => "Færa",
 'movearticle' => "Færa",
 'movenologin' => "Óinnskráð(ur)",
-'movenologintext' => "Þú verður að vera <a href=\"{{localurl:Kerfissíða:Userlogin}}\">innskráð(ur)</a> til  að geta fært síður.",
+'movenologintext' => "Þú verður að vera [[Kerfissíða:Userlogin|innskráð(ur)]] til  að geta fært síður.",
 'movepage' => "Færa síðu",
 'movepagebtn' => "Færa síðuna",
 'movepagetalktext' => "Spallsíða síðunnar verður sjálfkrafa færð með ef hún er til nema:
@@ -386,12 +383,12 @@ Legend: (nú) = núverandi útgáfa,
 verða færð á nýja nafnið og núverandi staðsetning mun
 breytast í tilvísun sem vísa mun á nýju staðsetninguna,
 tenglar í núverandi nafn munu hinsvegar ekki breytast,
-[[Kerfissíða:Maintenance|athugaðu]] að þetta búi ekki til margfaldar
+athugaðu að þetta búi ekki til margfaldar
 tilvísanir, það er á þína ábyrgð að tryggja það að tenglar haldi áfram
 að vísa á rétta síðu.
 
 Athugaðu að síðan mun '''ekki''' verða færð ef það er þegar síða á nafninu
-sem þú hyggst færa hana á, nema síða sú sé tóm eða tilvísun sem á sér enga 
+sem þú hyggst færa hana á, nema síða sú sé tóm eða tilvísun sem á sér enga
 breytingarsögu. Þú getur þar með fært síðuna aftur til baka án þess að
 missa breytingarsöguna, en ekki fært hana venjulega síðu.
 
@@ -422,7 +419,6 @@ mjög rótækar breytingar á vinsælum síðum og valdið titringi hjá öðrum
 'nextdiff' => "Næsta breyting →",
 'nextn' => "næstu $1",
 'nextrevision' => "Næsta útgáfa→",
-'noaffirmation' => "Staðfesta þarf að skráin brjóti ekki á höfundarrétti.",
 'noarticletext' => "<div style=\"border: 1px solid #ccc; padding: 7px; background: white;\">'''Það er ekki enn grein undir þessu nafni á [[{{SITENAME}}]].'''
 * '''[{{SERVER}}{{localurl:{{NAMESPACE}}:{{PAGENAME}}|action=edit}} Skrifa grein undir nafninu „{{PAGENAME}}“]'''
 * [[{{ns:special}}:Search/{{PAGENAME}}|Leita að „{{PAGENAME}}“]] í öðrum greinum og síðum.
@@ -463,12 +459,10 @@ mjög rótækar breytingar á vinsælum síðum og valdið titringi hjá öðrum
 'portal' => "Samfélagsgátt",
 'portal-url' => "Project:Samfélagsgátt",
 'powersearch' => "Leita",
-'powersearchtext' => "Leita í eftirfarandi nafnrýmum :<br/>
-$1<br/>
+'powersearchtext' => "Leita í eftirfarandi nafnrýmum :<br />
+$1<br />
 $2 Sýna tilvísarnir &nbsp; Leita að $3 $9",
 'preferences' => "Stillingar",
-'prefs-help-userdata' => "* <strong>Nafn</strong> (valfrjálst): Veljir þú að gefa upp nafn þitt verður það notað til að geta heimilda um skrifað efni.<br/>
-* <strong>Tölvupóstfang</strong> (valfrjálst): Gerir öðrum notendum kleyft að hafa samband við þig í gegnum {{SITENAME}} án þess að þú þurfir að gefa upp póstfang þitt, auk þess að vera notað til að senda þér nýtt lykilorð skyldir þú gleyma því gamla.",
 'prefs-misc' => "Aðrar stillingar",
 'prefs-personal' => "Notendaupplýsingar",
 'prefs-rc' => "Nýlegar breytingar og stubbar",
@@ -476,7 +470,7 @@ $2 Sýna tilvísarnir &nbsp; Leita að $3 $9",
 
 [[m:Help:Preferences|Stillingarhjálpin]] (á ensku)
 inniheldur útskýringu á valmöguleikunum.",
-'prefsnologintext' => "You must be <a href=\"/wiki/Special:Userlogin\">logged in</a>
+'prefsnologintext' => "You must be [[Special:Userlogin|logged in]]
 to set user preferences.",
 'preview' => "Forskoða",
 'previewnote' => " Það sem sést hér er aðeins forskoðun og hefur ekki enn verið vistað.",
@@ -484,20 +478,17 @@ to set user preferences.",
 'previousrevision' => "←Fyrri útgáfa",
 'prevn' => "síðustu $1",
 'printableversion' => "Prentvæn útgáfa",
-'printsubtitle' => "(From http://is.wikipedia.org)",
+'printsubtitle' => "(From {{SERVER}})",
 'protect' => "Vernda",
 'protectcomment' => "Ástæða",
 'protectedpagewarning' => "<!-- -->",
 'protectlogpage' => "Verndunarskrá",
 'protectpage' => "Vernda síðu",
-'protectreason' => "(gefðu ástæðu)",
 'protectsub' => "(Vernda „$1“)",
 'qbedit' => "Breyta",
 'qbsettings' => "Valblað",
-'qbsettingsnote' => "Þessi stilling virkar bara í „Venjulega“ og „Kölnarblátt“ þemanu.",
-'querybtn' => "Senda inn fyrirspurn",
 'randompage' => "Handahófsvalin síða",
-'rclinks' => "Sýna síðustu $1 breytingar síðustu $2 daga<br/>$3",
+'rclinks' => "Sýna síðustu $1 breytingar síðustu $2 daga<br />$3",
 'rclistfrom' => "Sýna breytingar frá og með $1",
 'rclsub' => "(á síðum sem tengd er í frá „$1“)",
 'rcnote' => "Að neðan eru síðustu <strong>$1</strong> breytingar síðustu <strong>$2</strong> daga.",
@@ -551,7 +542,7 @@ to set user preferences.",
 |}",
 'shortpages' => "Stuttar síður",
 'show' => "Sýna",
-'showhideminor' => "$1 minniháttar breytingar | $2 breytingar eftir vélmenni | $3 breytingar eftir notendur",
+'showhideminor' => "$1 minniháttar breytingar | $2 breytingar eftir vélmenni | $3 breytingar eftir notendur | $4 patrolled edits",
 'showingresults' => "Sýni <strong>$1</strong> niðurstöður frá og með #<strong>$2</strong>.",
 'showingresultsnum' => "Sýni <strong>$1</strong> niðurstöður frá og með #<strong>$2</strong>.",
 'showlast' => "Sýna síðustu $1 skrár raðaðar $2.",
@@ -565,19 +556,18 @@ to set user preferences.",
 Þar fyrir utan eru '''$2''' síður sem líklega teljast fullgildar greinar.
 
 '''$3''' síður hafa verið skoðaðar og '''$4''' breytingar hafa verið gerðar
-síðan vefurinn var settur up. Það reiknast sem '''$5''' breytingar 
+síðan vefurinn var settur up. Það reiknast sem '''$5''' breytingar
 á hverja síðu að meðaltali, og '''$6''' fléttingar fyrir hverja breytingu.",
 'sitesubtitle' => "Frjálsa alfræðiorðabókin",
 'sitesupport' => "Framlög",
 'sitetitle' => "Wikipedia",
 'skin' => "Þema",
-'spamprotectiontext' => "The page you wanted to save was blocked by the spam filter. This is probably caused by a link to an external site. 
+'spamprotectiontext' => "The page you wanted to save was blocked by the spam filter. This is probably caused by a link to an external site.
 
 You might want to check the following regular expression for patterns that are currently blocked:",
 'specialpage' => "Kerfissíða",
 'specialpages' => "Kerfissíður",
 'spheading' => "Almennar",
-'sqlquery' => "Fyrirspurn",
 'statistics' => "Tölfræði",
 'storedversion' => "Geymd útgáfa",
 'stubthreshold' => "Stubbamerkja allt undir",
@@ -608,7 +598,6 @@ You might want to check the following regular expression for patterns that are c
 'tog-editwidth' => "Innsláttarsvæði hefur fulla breidd",
 'tog-hideminor' => "Fela minniháttar breytingar",
 'tog-highlightbroken' => "Sýna brotna hlekki <a href=\"\" class=\"new\">svona</a> (annars: svona<a href=\"\" class=\"internal\">?</a>).",
-'tog-hover' => "Sýna hjálpartexta á wiki hlekkjum",
 'tog-justify' => "Jafna málsgreinar",
 'tog-minordefault' => "Láta breytingar vera sjálfgefnar sem minniháttar",
 'tog-nocache' => "Slökkva á flýtivistun síðna",
@@ -653,11 +642,10 @@ in active use.",
 'uploadbtn' => "Hlaða inn skrá",
 'uploadedimage' => "hlóð inn \"$1\"",
 'uploaderror' => "Villa í innhlaðningu",
-'uploadfile' => "Hlaða inn skrá",
 'uploadlog' => "innhlaðningarskrá",
 'uploadlogpage' => "Innhlaðningarskrá",
 'uploadnologin' => "Óinnskráð(ur)",
-'uploadnologintext' => "You must be <a href=\"/wiki/Special:Userlogin\">logged in</a>
+'uploadnologintext' => "You must be [[Special:Userlogin|logged in]]
 to upload files.",
 'uploadtext' => "'''Áður en skrá er hlaðið inn''':
 * Notaðu [[JPEG]] skráarsniðið fyrir ljósmyndir, [[GIF]] fyrir hreyfimyndir, [[PNG]] fyrir aðrar myndir og [[Ogg Vorbis]] fyrir hljóðskrár.
@@ -673,15 +661,16 @@ to upload files.",
 'userlogin' => "Innskrá",
 'userlogout' => "Útskrá",
 'userstats' => "Notendatölfræði",
-'userstatstext' => "Það eru '''$1''' skráðir notendur, þar af '''$2''' stjórnendur (sjá $3).",
+'userstatstext' => "Það eru '''$1''' skráðir notendur, þar af eru '''$2''' eða '''$4%''' stjórnendur (sjá $3).",
 'version' => "Útgáfa",
 'viewprevnext' => "Skoða ($1) ($2) ($3).",
 'viewsource' => "Skoða wikikóða",
 'viewtalkpage' => "Skoða umræðu",
 'wantedpages' => "Eftirsóttar síður",
 'watch' => "Vakta",
-'watchdetails' => "Fyrir utan spjallsíður eru $1 síða/síður á vaktlistanum þínum. Hægt er að 
-<a href='$4'>sýna heildarlistann og breyta honum</a>.",
+'val_tab' => 'Votta',
+'watchdetails' => "Fyrir utan spjallsíður eru $1 síða/síður á vaktlistanum þínum. Hægt er að
+[$4 sýna heildarlistann og breyta honum].",
 'watcheditlist' => "Þetta er listi yfir þínar vöktuðu síður raðað í
 stafrófsröð. Merktu við þær síður sem þú vilt fjarlægja
 af vaktlistanum og ýttu á 'fjarlægja merktar' takkan
@@ -707,12 +696,11 @@ Ekki gleyma að breyta Wikipedia stillingunum þínum.",
 'whitelistreadtext' => "Þú verður að [[Special:Userlogin|skrá þig inn]] til að lesa síður.",
 'whitelistreadtitle' => "Notandi verður að skrá sig inn til að geta lesið.",
 'wikipediapage' => "Sýna verkefnissíðu",
-'wikititlesuffix' => "Wikipedia, frjálsa alfræðiorðabókin",
 'wlnote' => "Að neðan eru síðustu <b>$1</b> breytingar síðustu <b>$2</b> klukkutíma.",
 'wlsaved' => "Þetta er vistuð útgáfa af vaktlistanum þínum.",
 'wlshowlast' => "Sýna síðustu $1 klukkutíma, $2 daga, $3",
-'wrong_wfQuery_params' => "Incorrect parameters to wfQuery()<br/>
-Function: $1<br/>
+'wrong_wfQuery_params' => "Incorrect parameters to wfQuery()<br />
+Function: $1<br />
 Query: $2",
 'wrongpassword' => "Uppgefið lykilorð er rangt. Vinsamlegast reyndu aftur.",
 'yourdiff' => "Mismunur",
@@ -737,20 +725,6 @@ class LanguageIs extends LanguageUtf8 {
 		return $wgNamespaceNamesIs;
 	}
 
-	function getNsText( $index ) {
-		global $wgNamespaceNamesIs;
-		return $wgNamespaceNamesIs[$index];
-	}
-
-	function getNsIndex( $text ) {
-		global $wgNamespaceNamesIs;
-
-		foreach ( $wgNamespaceNamesIs as $i => $n ) {
-			if ( 0 == strcasecmp( $n, $text ) ) { return $i; }
-		}
-		return false;
-	}
-
 	function getQuickbarSettings() {
 		global $wgQuickbarSettingsIs;
 		return $wgQuickbarSettingsIs;
@@ -761,15 +735,20 @@ class LanguageIs extends LanguageUtf8 {
 		return $wgSkinNamesIs;
 	}
 
+	function getDateFormats() {
+		global $wgDateFormatsIs;
+		return $wgDateFormatsIs;
+	}
+
 	function getMessage( $key ) {
 		global $wgAllMessagesIs;
 		if( isset( $wgAllMessagesIs[$key] ) ) {
 			return $wgAllMessagesIs[$key];
 		} else {
-			return Language::getMessage( $key );
+			return parent::getMessage( $key );
 		}
 	}
-	
+
 	function getAllMessages() {
 		global $wgAllMessagesIs;
 		return $wgAllMessagesIs;
@@ -779,32 +758,69 @@ class LanguageIs extends LanguageUtf8 {
 		global $wgMagicWordsIs;
 		return $wgMagicWordsIs;
 	}
-	
-	function date( $ts, $adj = false ) {
+
+	function date( $ts, $adj = false, $format = true) {
+		global $wgUser;
 		if ( $adj ) { $ts = $this->userAdjust( $ts ); } # Adjust based on the timezone setting.
-			
-		return (0 + substr( $ts, 6, 2 )) . '. ' .
-			$this->getMonthName( substr( $ts, 4, 2 ) ) . ' ' .
-			substr($ts, 0, 4);
+		$format = $this->dateFormat($format);
+
+		switch( $format ) {
+			# 15. jan. 2001 kl. 16:12 || 16:12, 15. jan. 2001
+			case '2': case '4': return (0 + substr( $ts, 6, 2 )) . '. ' .
+				$this->getMonthAbbreviation( substr( $ts, 4, 2 ) ) . '. ' .
+				substr($ts, 0, 4);
+			# 2001-01-15 16:12:34
+			case 'ISO 8601': return substr($ts, 0, 4). '-' . substr($ts, 4, 2). '-' .substr($ts, 6, 2);
+
+			# 15. janúar 2001 kl. 16:12 || 16:12, 15. janúar 2001
+			default: return (0 + substr( $ts, 6, 2 )) . '. ' .
+				$this->getMonthName( substr( $ts, 4, 2 ) ) . ' ' .
+				substr($ts, 0, 4);
+		}
+
 	}
 
-	function time($ts, $adj = false) {
+	function time($ts, $adj = false, $format = true) {
+		global $wgUser;
 		if ( $adj ) { $ts = $this->userAdjust( $ts ); } # Adjust based on the timezone setting.
-		
-		return substr( $ts, 8, 2 ) . ':' . substr( $ts, 10, 2 );
+
+		$format = $this->dateFormat($format);
+
+		switch( $format ) {
+			# 2001-01-15 16:12:34
+			case 'ISO 8601': return substr( $ts, 8, 2 ) . ':' . substr( $ts, 10, 2 ) . ':' . substr( $ts, 12, 2 );
+			default: return substr( $ts, 8, 2 ) . ':' . substr( $ts, 10, 2 );
+		}
+
 	}
 
-	function timeanddate( $ts, $adj = false ) {
-		return $this->time( $ts, $adj ) . ', ' . $this->date( $ts, $adj );
+	function timeanddate( $ts, $adj = false, $format = true) {
+		global $wgUser;
+
+		$format = $this->dateFormat($format);
+
+		switch ( $format ) {
+			# 16:12, 15. janúar 2001 || 16:12, 15. jan. 2001
+			case '3': case '4': return $this->time( $ts, $adj, $format ) . ', ' . $this->date( $ts, $adj, $format );
+			# 2001-01-15 16:12:34
+			case 'ISO 8601': return $this->date( $ts, $adj, $format ) . ' ' . $this->time( $ts, $adj, $format );
+			# 15. janúar 2001 kl. 16:12 || 15. jan. 2001 kl. 16:12
+			default: return $this->date( $ts, $adj, $format ) . ' kl. ' . $this->time( $ts, $adj, $format );
+
+		}
+
 	}
-	
+
 	/**
 	 * The Icelandic number style uses dots where English would use commas
 	 * and commas where English would use dots, e.g. 201.511,17 not 201,511.17
 	 */
-	function formatNum( $number ) {
-		global $wgTranslateNumerals;
-		return $wgTranslateNumerals ? strtr($number, '.,', ',.' ) : $number;
+	function formatNum( $number, $year = false ) {
+		return $year ? $number : strtr($this->commafy($number), '.,', ',.' );
+	}
+
+	function linkPrefixExtension() {
+		return true;
 	}
 }
 
